@@ -12,17 +12,15 @@ use Module::Pluggable search_path=>['Module::CPANTS::Generator'];
 use File::Copy;
 use File::Path;
 use IO::Capture::Stderr;
-use Module::CPANTS::Config;
 
 use vars qw($VERSION);
-$VERSION = "0.40";
-
+$VERSION = "0.41";
 
 ##################################################################
 # SETUP - on load
 ##################################################################
 
-__PACKAGE__->mk_accessors(qw(quiet generators config opts));
+__PACKAGE__->mk_accessors(qw(quiet generators opts lint_file));
 
 
 ##################################################################
@@ -34,7 +32,6 @@ sub new {
     my $opts=shift || {};
     
     my $cpants=bless {},$class;
-    $cpants->config(Module::CPANTS::Config->new());
     $cpants->opts($opts);
     
     my %generators;
@@ -55,77 +52,80 @@ sub analyse_cpan {
     
     my $limit=$self->opts->{'limit'} || 0;
     print "parsing packages info...\n";
-    my $p=Parse::CPAN::Packages->new($self->config->minicpan_02packages($self));
+    my $p=Parse::CPAN::Packages->new($self->minicpan_02packages($self));
     
     my %seen;
     my $all=Module::CPANTS::DB::Dist->retrieve_all;
     while (my $d=$all->next) {
         $seen{$d->package}++;
     }
-    my $now=localtime;
     
     foreach my $dist (sort {$a->dist cmp $b->dist} $p->latest_distributions) {
-        my $package=$dist->filename;
-        if ($package=~m|/|) {
-            $package=~s|^.*/||;
-        }
-
+        my $package=$dist->distvname;
+        
         next if $seen{$package};
         next if $package=~/^perl[-\d]/;
         next if $package=~/^ponie-/;
+        next if $package=~/^Perl6-Pugs/;
         next if $package=~/^parrot-/;
         next if $package=~/^Bundle-/;
- 
-        my $capture=IO::Capture::Stderr->new();
-        $capture->start;
-   
-        my $from=$self->config->minicpan_path_to_dist($dist->prefix);
-        my $to=catfile($self->config->testdir,$package);
-
-        if (-e $from) {
-            print "$package\n" unless $self->quiet;
-            copy ($from,$to) || warn "cannot copy $from to $to: $!";
-        } else {
-            warn "missing in mirror: $package\n" unless $self->quiet;
-            next;
-        }
         
-        my $dist=Module::CPANTS::DB::Dist->create({
-            package=>$package,
-            generated_at=>$now,
-            generated_with=>$VERSION,
-            testfile=>$to,
-            from=>$from
-        });
+        print $dist->distvname."\n" unless $self->quiet;
         
-        foreach my $gen (@{$self->generators}) {
-            last unless $gen->analyse($dist);
-        }
-        
-        eval {$dist->update};
-        warn $@ if $@;
-        
-        # remove testing dir
-        #   it's easier to delete the whole thing, as certain dist
-        #   put their content everywhere...
-        rmtree($self->config->testdir);
-        
-        # create new testing dir for next test
-        mkdir($self->config->testdir);
-        
-        $capture->stop;
-        my @errors=$capture->read;
-        if (@errors) {
-            $dist->cpants_errors(join("\n",@errors));
-            print "ERROR: ",@errors,"\n";
-            $dist->update;
-        }
+        my $file=$self->minicpan_path_to_dist($dist->prefix);
+        $self->analyse_dist($file);
         
         if ($limit) {
             $cnt++;
             last if $cnt>$limit;
         }
     }
+    $self->set_date;
+}
+    
+sub analyse_dist {
+    my $self=shift;
+    my $file=shift;
+  
+    my $capture=IO::Capture::Stderr->new();
+    $capture->start;
+   
+    # remove testing dir
+    #   it's easier to delete the whole thing, as certain dist
+    #   put their content everywhere...
+    rmtree($self->testdir);
+        
+    # create new testing dir for testing
+    mkdir($self->testdir);
+    
+    if (!-e $file) {
+        warn "package not found: $file\n" unless $self->quiet;
+        return;
+    }
+        
+    my $dist;
+    eval {
+        $dist=Module::CPANTS::DB::Dist->create({
+                #package=>$package,
+                #testfile=>$to,
+            from=>$file,
+        });
+    
+        foreach my $gen (@{$self->generators}) {
+            last unless $gen->analyse($dist);
+        }
+        
+        $dist->update;
+    };
+    warn $@ if $@;
+        
+    $capture->stop;
+    my @errors=$capture->read;
+    if (@errors) {
+        $dist->cpants_errors(join("\n",@errors));
+        print "ERROR: ",@errors,"\n";
+        $dist->update;
+    }
 }
 
 
@@ -166,6 +166,19 @@ sub get_indicators {
     return wantarray ? @indicators : \@indicators;
 }
 
+sub get_indicators_hash {
+    my $self=shift;
+
+    my %indicators;
+    foreach my $gen (@{$self->generators}) {
+        foreach my $ind (@{$gen->kwalitee_indicators}) {
+            $ind->{defined_in}=$gen;
+            $indicators{$ind->{name}}=$ind;
+        }
+    }
+    return \%indicators;
+}
+
 sub get_schema {
     my $self=shift;
 
@@ -203,6 +216,53 @@ sub get_schema_text {
     return $dump;
 }
 
+sub set_date {
+    my $self=shift;
+    my $version=$VERSION;
+    my $now=localtime;
+    my $dbh=Module::CPANTS::DB->db_Main;
+    $dbh->do("insert into version (?,?)",undef,$version,$now);
+    return;
+}
+
+
+
+#----------------------------------------------------------------
+# CONFIG STUFF
+#----------------------------------------------------------------
+
+# currently hardcoded, should be settable via ./Build
+sub basedir { '/home/domm/perl/Module-CPANTS-Generator/cpants/' }
+sub minicpan { '/home/minicpan/' }
+
+# config values induced from others
+sub db_file {
+    my $self=shift;
+    return catfile($self->basedir,'cpants.db');
+}
+sub prev_db_file { return catfile(shift->basedir,'cpants_previous.db') }
+
+sub minicpan_01mailrc {
+    my $self=shift;
+    return catfile($self->minicpan,'authors','01mailrc.txt.gz');
+}
+
+sub minicpan_02packages {
+    my $self=shift;
+    return catfile($self->minicpan,'modules','02packages.'.($self->opts->{'test'}?'cpants_'.$self->opts->{'test'}:'details').'.txt.gz');
+}
+
+sub minicpan_path_to_dist {
+    my $self=shift;
+    my $prefix=shift;
+    return catfile($self->minicpan,'authors','id',$prefix);
+}
+
+sub testdir {
+    return catfile(shift->basedir,'testing','tmp');
+}
+
+
 1;
 
 __END__
@@ -231,7 +291,7 @@ in the distribution in the following order:
 
 =item 1.
 
-fetch_cpan.pl
+generate_db.pl
 
 =item 2.
 
@@ -239,15 +299,11 @@ analyse_dists.pl
 
 =item 3.
 
-calc_basic_kwalitee.pl
+calc_kwalitee.pl
 
 =item 4.
 
-yaml2sqlite.pl
-
-=item 5.
-
-calc_complex_kwalitee.pl
+make_graphs.pl
 
 =back
 
@@ -257,7 +313,7 @@ The CPAN Testing Service.
 
 CPANTS Results can be viewed here:
 
-http://cpants.dev.zsi.at/
+http://cpants.perl.org/
 
 Here are various sources for more information:
 
